@@ -20,6 +20,8 @@ gen_crawl_event!(crawl_trade_swap, BitgetSwapWSClient, MessageType::Trade, subsc
 #[rustfmt::skip]
 gen_crawl_event!(crawl_l2_event_swap, BitgetSwapWSClient, MessageType::L2Event, subscribe_orderbook);
 #[rustfmt::skip]
+gen_crawl_event!(crawl_l2_topk_swap, BitgetSwapWSClient, MessageType::L2TopK, subscribe_orderbook_topk);
+#[rustfmt::skip]
 gen_crawl_event!(crawl_ticker_swap, BitgetSwapWSClient, MessageType::Ticker, subscribe_ticker);
 
 pub(crate) fn crawl_trade(
@@ -50,6 +52,20 @@ pub(crate) fn crawl_l2_event(
     }
 }
 
+pub(crate) fn crawl_l2_topk(
+    market_type: MarketType,
+    symbols: Option<&[String]>,
+    on_msg: Arc<Mutex<dyn FnMut(Message) + 'static + Send>>,
+    duration: Option<u64>,
+) -> Option<std::thread::JoinHandle<()>> {
+    match market_type {
+        MarketType::InverseSwap | MarketType::LinearSwap => {
+            crawl_l2_topk_swap(market_type, symbols, on_msg, duration)
+        }
+        _ => panic!("Bitget does NOT have the {} market type", market_type),
+    }
+}
+
 pub(crate) fn crawl_ticker(
     market_type: MarketType,
     symbols: Option<&[String]>,
