@@ -39,6 +39,18 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     )
 }
 
+#[test_case(MarketType::LinearSwap, "BTC_USDT")]
+#[test_case(MarketType::InverseSwap, "BTC_USD")]
+fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
+    gen_test_code!(
+        crawl_l2_topk,
+        EXCHANGE_NAME,
+        market_type,
+        symbol,
+        MessageType::L2TopK
+    )
+}
+
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
